# -*- coding=utf-8 -*-


class ICacheHelper(object):

    def set(self, key, value):
        pass

    def get(self, key):
        pass

    def delete(self, key):
        pass

    def hash_mset(self, key, value):
        pass

    def hash_get_all(self, key):
        pass
